@@ -1,14 +1,12 @@
-mod client;
+pub mod api;
 pub mod credentials;
 mod object_type;
 mod types;
 
 #[macro_use]
 mod macros;
-pub mod vm;
 
-pub use client::{Client, RestartError, RevertSnapshotError};
+pub use api::Client;
 pub use jsonrpsee_types::{Error as RpcError, JsonValue};
 pub use object_type::ObjectType;
-pub use types::{Snapshot, SnapshotId, Subscription, VmId};
-pub use vm::Vm;
+pub use types::Subscription;
